@@ -1,7 +1,7 @@
 import os
 import unittest
 
-from worker.data.operations import get_data_by_path
+from worker.data.operations import get_data_by_path, get_one_data_record
 from worker.data.serialization import obj2json, json2obj
 from worker.test.utils import file_to_json
 from worker.wellbore.factory import set_drillstring_and_create_wellbore
@@ -189,6 +189,52 @@ class TestSections(unittest.TestCase):
         self.assertAlmostEqual(wellbore.actual_drillstring[1].inner_diameter, wellbore_des.actual_drillstring[1].inner_diameter, 10)
         self.assertAlmostEqual(wellbore.actual_drillstring[1].top_depth, wellbore_des.actual_drillstring[1].top_depth, 10)
 
+    def test_overlapping_liners(self):
+        """
+        In this test case we are checking if the casings and liners
+        are set correctly even if the there are overlapping liners.
+        :return:
+        """
+
+        wits = get_one_data_record(asset_id=3083, collection="wits")
+        wellbore = set_drillstring_and_create_wellbore(wits)
+
+        hole: Hole = wellbore.actual_hole
+        hole_depth = 25633.01
+
+        self.assertEqual(3, len(hole))
+
+        self.assertEqual(HoleType.CASED_HOLE, hole[0].hole_type)
+        self.assertAlmostEqual(0.0, hole[0].top_depth, 1)
+        self.assertAlmostEqual(20633.0, hole[0].bottom_depth, 1)
+        self.assertAlmostEqual(4.28, hole[0].inner_diameter, 0.01)
+
+        self.assertEqual(HoleType.CASED_HOLE, hole[1].hole_type)
+        self.assertAlmostEqual(20633.0, hole[1].top_depth, 1)
+        self.assertAlmostEqual(23000.0, hole[1].bottom_depth, 1)
+        self.assertAlmostEqual(3.0, hole[1].inner_diameter, 0.01)
+
+        self.assertEqual(HoleType.OPEN_HOLE, hole[2].hole_type)
+        self.assertAlmostEqual(23000.0, hole[2].top_depth, 1)
+        self.assertAlmostEqual(hole_depth, hole[2].bottom_depth, 1)
+        self.assertAlmostEqual(2.85, hole[2].inner_diameter, 0.01)
+
+    def test_creating_wellbore_with_missing_drillstring(self):
+        wits_record = {
+            "collection": "wits",
+            "asset_id": 10477107,
+            "metadata": {
+                'drillstring': '5f4d5bf1150c40007f3a12fc'
+            },
+            "data": {
+                "bit_depth": 1111,
+                "hole_depth": 1111
+            }
+        }
+
+        wellbore = set_drillstring_and_create_wellbore(wits_record)
+        self.assertIsNone(wellbore)
+
 
 def get_wits():
     wits_json_file = os.path.abspath(
