@@ -38,6 +38,7 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
         :return:
         """
         event_type = self.get_event_type()
+        valid_stream_collections = self.get_valid_stream_collections()
         event = self.clean_event(event)
 
         max_lookback_seconds = self.get_max_lookback_seconds()
@@ -46,7 +47,8 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
 
         self.state = self.load_state()
 
-        self.event = self.load_event(event_type, event, max_lookback_seconds)
+        event = self.load_event(event_type, event, max_lookback_seconds)
+        self.event = self.filter_event_for_collections(event_type, valid_stream_collections, event)
         self.log_event(self.event, max_lookback_seconds)
 
     def log_event(self, event, max_lookback_seconds):
@@ -76,6 +78,16 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
 
         return event_type
 
+    @staticmethod
+    def get_valid_stream_collections():
+        valid_collections = constants.get('global.valid-stream-collections', [])
+        if not isinstance(valid_collections, (str, list)):
+            raise TypeError("Incorrect type of valid-stream-collections in global constants")
+
+        if isinstance(valid_collections, str):
+            valid_collections = [valid_collections]
+        return valid_collections
+
     @staticmethod
     def clean_event(event):
         if not event:
@@ -114,6 +126,25 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
 
         return None
 
+    @staticmethod
+    def filter_event_for_collections(event_type: str, valid_stream_collections: list, event: list):
+        """
+        This function filters the incoming event based on a list of valid collections
+
+        :param event_type: Type of incoming event.
+        :param valid_stream_collections: List of valid collections
+        :param event: List of data records
+        :return: List of records whose collection is one of the allowed event collections
+        """
+
+        # If event type is scheduler or event_collections is empty, return the entire event
+        if event_type == 'scheduler' or not valid_stream_collections:
+            return event
+
+        # Filtering the event based on valid collections
+        event = [record for record in event if record.get("collection") in valid_stream_collections]
+        return event
+
     def load_scheduler_event(self, asset_id, event, max_lookback_seconds):
         """
         To load a scheduler event and get the wits stream data
@@ -217,8 +248,8 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
         except Exception:
             raise Exception('Event does not contain asset_id: {}'.format(event))
 
-    def load_state(self, state_key: [str, None] = None, auto_migrate: bool = False) -> dict:
-        previous_state = super().load_state(state_key=state_key, auto_migrate=auto_migrate)
+    def load_state(self, state_key: [str, None] = None, auto_migrate: bool = False, raise_warnings: bool = False) -> dict:
+        previous_state = super().load_state(state_key=state_key, auto_migrate=auto_migrate, raise_warnings=raise_warnings)
 
         state = State(self.app_state_fields, previous_state)
 
@@ -227,11 +258,11 @@ class App(StateMixin, LoggingMixin, RollbarMixin):
 
         return state
 
-    def save_state(self, state_key: [str, None] = None, timestamp: [int, None] = None):
+    def save_state(self, state_key: [str, None] = None, timestamp: [int, None] = None, raise_warnings: bool = True) -> None:
         if not timestamp:
             timestamp = self.state.get('last_processed_timestamp', 0)
 
-        super().save_state(state_key=state_key, timestamp=timestamp)
+        super().save_state(state_key=state_key, timestamp=timestamp, raise_warnings=raise_warnings)
 
     def get_modules(self):
         raise exceptions.Misconfigured("No modules found")
