@@ -49,8 +49,8 @@ class Module(StateMixin, LoggingMixin, RollbarMixin):
     def should_run_processor(self, event):
         raise Exception("This method need to be implemented by subclasses!")
 
-    def load_state(self, state_key: [str, None] = None, auto_migrate: bool = False) -> dict:
-        current_state = super().load_state(state_key=state_key, auto_migrate=auto_migrate)
+    def load_state(self, state_key: [str, None] = None, auto_migrate: bool = False, raise_warnings: bool = False) -> dict:
+        current_state = super().load_state(state_key=state_key, auto_migrate=auto_migrate, raise_warnings=raise_warnings)
         return State(self.module_state_fields, current_state)
 
     @staticmethod
@@ -60,11 +60,11 @@ class Module(StateMixin, LoggingMixin, RollbarMixin):
     def set_state(self, key, value):
         self.state[key] = value
 
-    def save_state(self, state_key: [str, None] = None, timestamp: [int, None] = None):
+    def save_state(self, state_key: [str, None] = None, timestamp: [int, None] = None, raise_warnings: bool = True) -> None:
         if not timestamp:
             timestamp = self.global_state.get('last_processed_timestamp', 0)
 
-        super().save_state(state_key=state_key, timestamp=timestamp)
+        super().save_state(state_key=state_key, timestamp=timestamp, raise_warnings=raise_warnings)
 
     def load_dataset(self, event):
         return event
