@@ -3,7 +3,7 @@ from itertools import groupby
 from worker.app.modules.__init__ import Module
 from worker.data.api import API
 from worker.data import operations
-from worker.exceptions import NotFound
+from worker.data.operations import get_drillstring_by_id
 from worker.framework import constants
 
 
@@ -34,7 +34,7 @@ class ActivityModule(Module):
             if self.should_run_processor(group):
                 results = self.run_module(group, results)
 
-            self.save_module_state()
+            self.save_state()
             self.store_output(self.global_state['asset_id'], results)
 
     @staticmethod
@@ -107,7 +107,7 @@ class ActivityModule(Module):
                 'message': message
             }
 
-            if active_string_type not in reset_config:
+            if active_string_type not in reset_config and self.collection:
                 # get the last record
                 worker = API()
                 last_document = worker.get(
@@ -141,11 +141,7 @@ class ActivityModule(Module):
 
         drillstring_number = None
         if active_string_type == 'drillstring':
-            drillstring = None
-            try:
-                drillstring = API().get_by_id(path="/v1/data/corva/", collection='data.drillstring', id=active_string_id).data
-            except NotFound:
-                pass
+            drillstring = get_drillstring_by_id(active_string_id)
 
             if drillstring:
                 drillstring_number = drillstring.get('data', {}).get('id', None)
