@@ -4,8 +4,10 @@ from typing import List, Tuple, Union
 
 import numpy as np
 
+from worker.data import math
 from worker.data.api import API
 from worker.data.enums import EventTypes, Environment
+from worker.data.wits import WITS
 from worker.exceptions import NotFound
 
 
@@ -204,6 +206,30 @@ def is_int(s: str) -> bool:
         return False
 
 
+def is_null(value) -> bool:
+    """
+    Will return True if the value is null, None, any variant of -999.25
+
+    :param value:
+    :return:
+    """
+    value = to_number(value)
+    if value is None:
+        return True
+
+    if value >= 0:
+        return False
+
+    value = str(value)
+    for each in ["-", ".", "0"]:
+        value = value.replace(each, "")
+
+    if value == "99925":
+        return True
+
+    return False
+
+
 def to_number(data):
     """
     Check and return if the data can be cast to a number, else return None
@@ -369,3 +395,34 @@ def get_cleaned_event_and_type(event) -> Tuple[Union[list, dict], EventTypes]:
         return event, EventTypes.STREAM
 
     raise TypeError("Event is not either a scheduler or kafka consumer")
+
+
+def compute_time_step(records: Union[List[WITS], List[float]], percent=50) -> Union[int, None]:
+    """
+    Compute the time step of the wits records
+    If the intention is to split the data based on their activities a higher percent
+    is recommended (such as 99%). For other cases 50% might work.
+
+    :param records: a list of WITS records
+    :param percent: this is an important parameter to get the correct time step
+    :return:
+    """
+    if len(records) <= 3:
+        return None
+
+    if not 0 <= percent <= 100:
+        raise ValueError(f"percent ({percent}) is out of [0, 100] range.")
+
+    if isinstance(records[0], WITS):
+        timestamps = [rec.timestamp for rec in records]
+    else:
+        timestamps = records
+
+    # a list of time steps for all the timestamps
+    diffs = np.diff(timestamps)
+
+    time_step = math.percentile(diffs, percent)
+    if not time_step:
+        return None
+
+    return int(time_step)
