@@ -35,11 +35,12 @@ class StateMixin(LoggingMixin, RollbarMixin):
         if self.state_storage_type == StateStorageType.MONGO:
             return MongoStateHandler()
 
-    def load_state(self, state_key: [str, None] = None, auto_migrate: bool = False) -> dict:
+    def load_state(self, state_key: [str, None] = None, auto_migrate: bool = False, raise_warnings: bool = False) -> dict:
         """
         Load the state from mongo or redis
         :param state_key:
         :param auto_migrate: Set to True if auto-migration from one state storage service to current is needed
+        :param raise_warnings: Set to True if size limits warnings should be printed
         :return:
         """
         if not state_key:
@@ -47,27 +48,32 @@ class StateMixin(LoggingMixin, RollbarMixin):
 
         state = self.state_handler.load_state(self.asset_id, state_key)
 
+        # if auto_migrate key is not passed in, attempt to get from environment
+        if not auto_migrate:
+            auto_migrate = os.getenv("AUTO_MIGRATE_STATE", "false").lower() == "true"
+
         if not state and auto_migrate:
             state = self.state_handler.migrate_state(self.asset_id, state_key)
             self.info(self.asset_id, f"Migrated state storage to {self.state_storage_type.value}.")
 
-        size_object = self.state_handler.check_state_size(self.asset_id, state, state_key, raise_warnings=False)
+        size_object = self.state_handler.check_state_size(self.asset_id, state, state_key, raise_warnings=raise_warnings)
 
         self.debug(self.asset_id, f"Retrieved state from {self.state_storage_type.value} of size {size_object} kb")
         self.state = state
         return state
 
-    def save_state(self, state_key: [str, None] = None, timestamp: [int, None] = None) -> None:
+    def save_state(self, state_key: [str, None] = None, timestamp: [int, None] = None, raise_warnings: bool = True) -> None:
         """
         Save the state to mongo or redis
         :param state_key:
         :param timestamp:
+        :param raise_warnings: Set to True if size limits warnings should be printed
         :return:
         """
         if not state_key:
             state_key = self.get_formatted_state_key(self.asset_id, self.app_key, self.module_key)
 
-        size_object = self.state_handler.check_state_size(self.asset_id, self.state, state_key, raise_warnings=True)
+        size_object = self.state_handler.check_state_size(self.asset_id, self.state, state_key, raise_warnings=raise_warnings)
         self.state_handler.save_state(self.asset_id, self.state, state_key, timestamp)
         self.debug(self.asset_id, f"Saved state to {self.state_storage_type.value} of size {size_object} kb")
 
