@@ -26,63 +26,93 @@ import os
 from distutils.util import strtobool
 from typing import List
 
+from dotenv import load_dotenv
 from tqdm import tqdm
 
-import worker.framework.constants as constants
-from worker.data.operations import delete_collection_data_of_asset_id, get_one_data_record, gather_data_for_period
+from worker.data.operations import delete_collection_data_of_asset_id, get_one_data_record, gather_data_for_period, \
+    point_main_envs
 from worker.state.mixins import StateMixin
 from worker.test.utils import get_last_processed_timestamp, create_scheduler_events
 
 
-def generate_parser():
+load_dotenv(override=True)
+
+
+def generate_runner_parser():
     """
     Creating the supporting arguments
     :return:
     """
-    parser = argparse.ArgumentParser(description="Run your tests locally on an asset.")
-    parser.add_argument("-a", "--asset_id", "--id", type=int, required=True, help="set asset_id")
-    parser.add_argument("-s", "--start_timestamp", "--start", type=int, required=False, default=None, help="start timestamp")
-    parser.add_argument("-e", "--end_timestamp", "--end", type=int, required=False, default=None, help="end timestamp")
-    parser.add_argument("-i", "--timestep", "--step", type=int, required=False, default=60, help="trigger the lambda function once every step")
-    parser.add_argument("-t", "--event_type", "--event", type=str, required=False, default="scheduler", help="type of event, scheduler or wits_stream")
-    parser.add_argument("-d", "--to_delete", "--delete", type=strtobool, required=False, default=False, help="to delete the state and data")
-    parser.add_argument("-g", "--storage_type", "--storage", type=str, required=False, default="redis", help="type of state storage, redis or mongo")
+    parser = argparse.ArgumentParser(description="Run your tests on an asset.")
+    parser.add_argument("-v", "--environment", "--env", type=str, required=False,
+                        help="environment, options: 'local', 'qa', 'staging', 'production'")
+    parser.add_argument("-a", "--asset_id", "--id", type=int, required=True,
+                        help="set asset_id")
+    parser.add_argument("-s", "--start_timestamp", "--start", type=int, required=False, default=None,
+                        help="start timestamp")
+    parser.add_argument("-e", "--end_timestamp", "--end", type=int, required=False, default=None,
+                        help="end timestamp")
+    parser.add_argument("-i", "--timestep", "--step", type=int, required=False, default=60,
+                        help="trigger the lambda function once every step")
+    parser.add_argument("-d", "--to_delete", "--delete", type=strtobool, required=False, default=False,
+                        help="to delete the state and data")
+    parser.add_argument("-g", "--storage_type", "--storage", type=str, required=False, default="redis",
+                        help="type of state storage, redis or mongo")
     return parser
 
 
 class AppTestRun:
-    def __init__(self, lambda_handler, collections, args=None):
-
+    def __init__(self, lambda_handler, collections: List[str], constants=None, args: List[str] = None):
+        """
+        :param lambda_handler: lambda handler function to run
+        :param collections: collections to erase in case to_delete is on
+        :param constants: constants module of the whole app, if there is only one app in the whole repository
+        pass nothing and the code takes care of that
+        :param args: arguments for the run
+        """
         self.lambda_handler = lambda_handler
         self.collections = collections
 
+        if not constants:
+            from worker import constants
+
+        self.constants = constants
+
         self.event_type = None
         self.progress = None
 
         if args is None:
-            parser = generate_parser()
+            parser = generate_runner_parser()
             args = parser.parse_args()
 
         self.initialize(args)
 
     def initialize(self, args):
+        environment = args.environment
+
+        # directing main environment variables to the provided env: API_KEY, API_ROOT_URL, CACHE_URL
+        point_main_envs(environment)
+
         asset_id = args.asset_id
 
         start_timestamp = args.start_timestamp
         end_timestamp = args.end_timestamp
         step = args.timestep
-        self.event_type = args.event_type
+        self.event_type = self.constants.get('global.event-type')
         to_delete = args.to_delete
 
         # Setup state storage type environment
         state_storage_type = args.storage_type.lower()
         os.environ["STATE_STORAGE_TYPE"] = state_storage_type
 
-        state_keys = construct_state_keys(constants, asset_id)
+        state_keys = construct_state_keys(self.constants, asset_id)
+
         if not start_timestamp:
             start_timestamp = get_one_data_record(asset_id, timestamp_sort=+1).get('timestamp')
+
         if not end_timestamp:
             end_timestamp = get_one_data_record(asset_id, timestamp_sort=-1).get('timestamp')
+
         if to_delete:
             delete_state_data_of_asset_id(asset_id, state_keys, state_storage_type=state_storage_type)
             delete_collection_data_of_asset_id(asset_id, self.collections)
@@ -96,18 +126,19 @@ class AppTestRun:
         self.progress = tqdm(events, ncols=150)
 
     def run(self):
-        for e in self.progress:
-            schedule_time = str(int(e[0][0]['schedule_start'] / 1000))
+        print("\nRunning the main module started ...")
+        for event in self.progress:
+            schedule_time = str(int(event[0][0]['schedule_start'] / 1000))
             if self.event_type == "wits_stream":
                 wits = gather_data_for_period(
-                    int(e[0][0]['asset_id']),
-                    int(e[0][0]['schedule_start'] / 1000),
-                    int(e[0][0]['schedule_end'] / 1000)
+                    int(event[0][0]['asset_id']),
+                    int(event[0][0]['schedule_start'] / 1000),
+                    int(event[0][0]['schedule_end'] / 1000)
                 )
                 if not wits:
                     continue
-                e = [wits]
-            self.lambda_handler(e, None)
+                event = [wits]
+            self.lambda_handler(event, None)
             self.progress.set_description(schedule_time)
 
         # Reset environment for other tests
